@@ -1,4 +1,4 @@
-const createInfuraProvider = require('eth-json-rpc-infura/src/createProvider')
+const createInfuraProvider = require('@trufflesuite/eth-json-rpc-infura/src/createProvider')
 const ProviderSubprovider = require('./provider.js')
 
 class InfuraSubprovider extends ProviderSubprovider {
